/*
 * Copyright (c) 2018. Developed by Hedgecode.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.hedgecode.chess.uci;

import java.io.InputStream;
import java.util.Scanner;

/**
 *
 *
 * @author Dmitry Samoshin aka gotty
 */
public class ExternalEngineTransmitter implements Transmitter<String> {

    private Scanner scanner;
    private boolean isActive;

    ExternalEngineTransmitter(InputStream input) {
        scanner = new Scanner(input);
        isActive = true;
    }

    @Override
    public boolean isActive() {
        return isActive;
    }

    @Override
    public boolean hasCommand() {
        return isActive && scanner.hasNextLine();
    }

    @Override
    public String transmitCommand() {
        return scanner.nextLine();
    }

    @Override
    public void addCommand(String command) {
        // not supported for external engine
    }

    @Override
    public void stop() {
        isActive = false;
    }

    @Override
    public void close() {
        scanner.close();
    }

}
